# -*- mode: cmake -*-
# This file used to configure CMake variables that are used to build the
# installed examples.
# Identify that this is the build system for the installed examples.
set(BUILD_TEST ON)
set(CORE_BUILD OFF)

# =======================================================================
# Useful functions.
# =======================================================================
include(plplot_functions)

# =======================================================================
# pkg-config support as well as macros to put link flags in standard
# *.pc (pkg-config) form as well as standard fullpath form used by cmake.
# PKG_CONFIG_EXECUTABLE can be used to discover whether pkg-config was
# found or not.
# =======================================================================
include(pkg-config)

set(INCLUDE_DIR "/usr/include/plplot")
set(CMAKE_PREFIX_PATH "/usr")
set(MATH_LIB /usr/lib64/libm.so)
set(SH_EXECUTABLE /usr/bin/bash)

set(BUILD_SHARED_LIBS ON)

set(language_info_LIST ada:ada:a;c:c:c;cxx:c++:cxx;d:d:d;f95:f95:f95;java:java:j;lua:lua:lua;ocaml:ocaml:ocaml;octave:octave:o;pdl:perl:pdl;python:python:p;tcl:tcl:t;plrender:c:plm)

# This list of set commands must be consistent with language_info_LIST
# set in examples/CMakeLists.txt and configured just above.  Thus,
# some consistent maintenance of that list and the current list of set
# commands must be done on the rare occasions when a language is added
# to PLplot.  Cannot make the list of set commands automatically with
# a foreach loop because explicit configuration of each name is required.
set(ENABLE_ada ON)
set(ENABLE_c ON)
set(ENABLE_cxx ON)
set(ENABLE_d OFF)
set(ENABLE_f95 ON)
set(ENABLE_java ON)
set(ENABLE_lua ON)
set(ENABLE_ocaml ON)
set(ENABLE_octave ON)
set(ENABLE_pdl OFF)
set(ENABLE_python ON)
set(ENABLE_pyqt4 ON)
set(ENABLE_tcl ON)

# Interactive bindings
set(ENABLE_tk ON)
set(ENABLE_tkX ON)
set(OLD_WXWIDGETS OFF)
set(wxdemo_name wxPLplotDemo)
set(ENABLE_wxwidgets ON)
set(ENABLE_qt ON)

# Check for all officially supported CMake compilers that we use with
# soft-landing support.
include(language_support)

# First field is lower-case language string, second field is
# mixed-case language string used for official CMake variables, third
# field is language string to be used in output messages, and final
# field is whether it is a fatal error if this language is missing/not
# working.
set(COMPILED_LANGUAGE_INFO_LIST
"c:C:C:ON"
"ada:Ada:Ada:OFF"
"cxx:CXX:C++:OFF"
"d:D:D:OFF"
"f95:Fortran:Fortran:OFF"
"java:Java:Java:OFF"
)

foreach(COMPILED_LANGUAGE_INFO ${COMPILED_LANGUAGE_INFO_LIST})
  string(REGEX REPLACE "^(.*):.*:.*:.*$" "\\1" language ${COMPILED_LANGUAGE_INFO})
  string(REGEX REPLACE "^.*:(.*):.*:.*$" "\\1" Language ${COMPILED_LANGUAGE_INFO})
  string(REGEX REPLACE "^.*:.*:(.*):.*$" "\\1" language_output ${COMPILED_LANGUAGE_INFO})
  string(REGEX REPLACE "^.*:.*:.*:(.*)$" "\\1" fatal_language ${COMPILED_LANGUAGE_INFO})
  if(ENABLE_${language} AND NOT PLPLOT_${Language}_COMPILER_WORKS)
    workaround_9220(${Language} PLPLOT_${Language}_COMPILER_WORKS)
    if(NOT PLPLOT_${Language}_COMPILER_WORKS)
      if(fatal_language)
	message(FATAL_ERROR "${language_output} compiler absolutely required to build this project.")
      endif(fatal_language)
      message(STATUS "WARNING: no working ${language_output} compiler so disabling ${language} examples.")
      set(ENABLE_${language} OFF CACHE BOOL "Enable ${language} bindings" FORCE)
    endif(NOT PLPLOT_${Language}_COMPILER_WORKS)
  endif(ENABLE_${language} AND NOT PLPLOT_${Language}_COMPILER_WORKS)

  if(ENABLE_${language})
    # Find and check ${Language} compiler
    enable_language(${Language} OPTIONAL)
    if(NOT CMAKE_${Language}_COMPILER_WORKS)
      if(fatal_language)
	message(FATAL_ERROR "${language_output} compiler absolutely required to build this project.")
      endif(fatal_language)
      message(STATUS "WARNING: no working ${language_output} compiler so disabling ${language} examples.")
      set(ENABLE_${language} OFF CACHE BOOL "Enable ${language} bindings" FORCE)
    endif(NOT CMAKE_${Language}_COMPILER_WORKS)
  endif(ENABLE_${language})
endforeach(COMPILED_LANGUAGE_INFO ${COMPILED_LANGUAGE_INFO_LIST})

if(ENABLE_ada)
  set(ADA_INCLUDE_DIR "/usr/share/ada/adainclude/plplotada")
  set(ADA_LIB_DIR "/usr/lib64/ada/adalib/plplotada")
endif(ENABLE_ada)

if(ENABLE_f95)
  set(F95_MOD_DIR "/usr/lib64/gfortran/modules")
endif(ENABLE_f95)

if(ENABLE_java)
  find_package(JNI)
  set(JAR_DIR "/usr/share/java")
endif(ENABLE_java)

if(ENABLE_ocaml)
  set(OCAMLC /usr/bin/ocamlc.opt)
  set(OCAMLOPT /usr/bin/ocamlopt.opt)
  set(OCAMLFIND /usr/bin/ocamlfind)
  set(OCAML_HAS_CAIRO ON)
  set(OCAML_HAS_GTK ON)
  set(CMAKE_INSTALL_LIBDIR "/usr/lib64")
  set(OCAML_INSTALL_DIR "/usr/lib64/ocaml")
endif(ENABLE_ocaml)

if(ENABLE_tcl OR ENABLE_tk)
  set(TCL_TCLSH "/bin/tclsh")
  set(MKTCLINDEX ${CMAKE_SOURCE_DIR}/tcl/mktclIndex)
  set(MKTCLINDEX_ARGS -tcl)
  # Needed to configure tclsh_standard_examples and wish_standard_examples
  set(DATA_DIR /usr/share/plplot5.11.1)
endif(ENABLE_tcl OR ENABLE_tk)

if(ENABLE_tk)
  set(ENABLE_itk OFF)
  set(ENABLE_itkX OFF)
  set(TCL_INCLUDE_PATH "/usr/include")
  set(TK_INCLUDE_PATH "/usr/include;/usr/include")
  set(TCL_LIBRARY "/usr/lib64/libtcl.so")
  set(TK_LIBRARY "/usr/lib64/libtk.so")
endif(ENABLE_tk)

if(ENABLE_wxwidgets)
  # Use identical compile and link flags to build wxwidgets application.
  set(wxwidgets_COMPILE_FLAGS "-I/usr/lib64/wx/include/gtk2-unicode-release-2.8 -I/usr/include/wx-2.8 -D_FILE_OFFSET_BITS=64 -D_LARGE_FILES -D__WXGTK__ ")
  set(wxwidgets_LINK_FLAGS -pthread;-Wl,-z,relro;-specs=/usr/lib/rpm/redhat/redhat-hardened-ld;/usr/lib64/libwx_baseu-2.8.so;/usr/lib64/libwx_gtk2u_core-2.8.so)
endif(ENABLE_wxwidgets)

if(ENABLE_qt)
  set(CORE_QT_VERSION_MAJOR 4)
  set(CORE_QT_VERSION_MINOR 8)
  set(CORE_QT_VERSION_PATCH 7)
endif(ENABLE_qt)

set(ENABLE_DYNDRIVERS ON)

set(FILE_DEVICES_LIST pdfcairo:cairo:OFF;pngcairo:cairo:ON;pscairo:cairo:OFF;epscairo:cairo:ON;svgcairo:cairo:ON;epsqt:qt:ON;pdfqt:qt:ON;bmpqt:qt:ON;jpgqt:qt:ON;pngqt:qt:ON;ppmqt:qt:ON;tiffqt:qt:ON;svgqt:qt:ON;ps:ps:OFF;pstex:pstex:OFF;psttf:psttf:OFF;svg:svg:ON;xfig:xfig:ON;psttfc:psttf:OFF)
# This list of set commands must be consistent with the above list which
# implies a maintenance issue.
set(PLD_pdfcairo ON)
set(PLD_pngcairo ON)
set(PLD_pscairo ON)
set(PLD_epscairo ON)
set(PLD_svgcairo ON)
set(PLD_cgm OFF)
set(PLD_epsqt ON)
set(PLD_pdfqt ON)
set(PLD_bmpqt ON)
set(PLD_jpgqt ON)
set(PLD_pngqt ON)
set(PLD_ppmqt ON)
set(PLD_tiffqt ON)
set(PLD_svgqt ON)
set(PLD_gif OFF)
set(PLD_jpeg OFF)
set(PLD_png OFF)
set(PLD_pdf OFF)
set(PLD_ps ON)
set(PLD_pstex ON)
set(PLD_psttf ON)
set(PLD_svg ON)
set(PLD_wxpng OFF)
set(PLD_xfig ON)

# These only used for testing, but not core build
set(PLD_psc ON)
set(PLD_psttfc ON)

set(INTERACTIVE_DEVICES_LIST xcairo:cairo;qtwidget:qt;ntk:ntk;tk:tk;wxwidgets:wxwidgets;xwin:xwin)
# Set interactive devices that are needed to build certain examples.  This
# list should be consistent with INTERACTIVE_DEVICES_LIST which implies a
# maintenance issue.

set(PLD_aqt OFF)
set(PLD_ntk ON)
set(PLD_qtwidget ON)
set(PLD_tk ON)
set(PLD_wincairo OFF)
set(PLD_wingcc OFF)
set(PLD_wxwidgets ON)
set(PLD_xcairo ON)
set(PLD_xwin ON)

# Set external devices that are needed to build certain examples.
set(PLD_extcairo ON)
set(PLD_extqt ON)

# Needed to check if diff and tail on system for test_diff_psc target.

set(DIFF_EXECUTABLE /usr/bin/diff)
set(TAIL_EXECUTABLE /usr/bin/tail)
set(CMP_EXECUTABLE /usr/bin/cmp)

# ocaml examples build needs this.
set(USE_RPATH OFF)

# WIN32 and CYGWIN derived variables
set(WIN32_AND_NOT_CYGWIN )
set(WIN32_OR_CYGWIN OFF)

#Qt5 support
set(PLPLOT_USE_QT5 OFF)

# Needed for Tcl/Tk linking decisions.
set(tcltk_in_plplot_library OFF)
